Join [the Game Theory Discord](https://github.com/drvinceknight/equilibrium_explorers)
server to chat — [direct invite link](https://discord.gg/NfTAkhAeyc).

# Sold

A python library for the study of Auctions

## Tutorial

## How To?

## Discussion

## Reference
